summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorDavid Gwynne <dlg@cvs.openbsd.org>2005-08-05 03:07:42 +0000
committerDavid Gwynne <dlg@cvs.openbsd.org>2005-08-05 03:07:42 +0000
commit2820e3e9c692ea8ac76b3e1a102ad1959ec9a1b9 (patch)
tree5e11b523a02c39ea9a5219ed04d8f97c731bfa5e /sys
parentf39d3fe8adcca3c8ec9f97c1d841716463999ce0 (diff)
add a sensor type that can report percentage
ok deraadt@
Diffstat (limited to 'sys')
-rw-r--r--sys/sys/sensors.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/sys/sys/sensors.h b/sys/sys/sensors.h
index 48d37af9394..15c28163bfa 100644
--- a/sys/sys/sensors.h
+++ b/sys/sys/sensors.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: sensors.h,v 1.6 2005/08/03 14:53:39 dlg Exp $ */
+/* $OpenBSD: sensors.h,v 1.7 2005/08/05 03:07:41 dlg Exp $ */
/*
* Copyright (c) 2003, 2004 Alexander Yurchenko <grange@openbsd.org>
@@ -40,7 +40,8 @@ enum sensor_type {
SENSOR_WATTHOUR, /* power capacity */
SENSOR_AMPHOUR, /* power capacity */
SENSOR_INDICATOR, /* boolean indicator */
- SENSOR_INTEGER /* generic integer value */
+ SENSOR_INTEGER, /* generic integer value */
+ SENSOR_PERCENT /* percent */
};
/* Sensor states */